==> route53-1.60.0-sources.jar: software/amazon/awscdk/services/route53/CfnHealthCheckProps.java <==
package software.amazon.awscdk.services.route53;

/**
 * Properties for defining a `AWS::Route53::HealthCheck`.
 * <p>
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53-healthcheck.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.263Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.route53.$Module.class, fqn = "@aws-cdk/aws-route53.CfnHealthCheckProps")
@software.amazon.jsii.Jsii.Proxy(CfnHealthCheckProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnHealthCheckProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::Route53::HealthCheck.HealthCheckConfig`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53-healthcheck.html#cfn-route53-healthcheck-healthcheckconfig
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getHealthCheckConfig();

    /**
     * `AWS::Route53::HealthCheck.HealthCheckTags`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53-healthcheck.html#cfn-route53-healthcheck-healthchecktags
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getHealthCheckTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnHealthCheckProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnHealthCheckProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnHealthCheckProps> {
        private java.lang.Object healthCheckConfig;
        private java.lang.Object healthCheckTags;

        /**
         * Sets the value of {@link CfnHealthCheckProps#getHealthCheckConfig}
         * @param healthCheckConfig `AWS::Route53::HealthCheck.HealthCheckConfig`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder healthCheckConfig(software.amazon.awscdk.services.route53.CfnHealthCheck.HealthCheckConfigProperty healthCheckConfig) {
            this.healthCheckConfig = healthCheckConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnHealthCheckProps#getHealthCheckConfig}
         * @param healthCheckConfig `AWS::Route53::HealthCheck.HealthCheckConfig`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder healthCheckConfig(software.amazon.awscdk.core.IResolvable healthCheckConfig) {
            this.healthCheckConfig = healthCheckConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnHealthCheckProps#getHealthCheckTags}
         * @param healthCheckTags `AWS::Route53::HealthCheck.HealthCheckTags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder healthCheckTags(software.amazon.awscdk.core.IResolvable healthCheckTags) {
            this.healthCheckTags = healthCheckTags;
            return this;
        }

        /**
         * Sets the value of {@link CfnHealthCheckProps#getHealthCheckTags}
         * @param healthCheckTags `AWS::Route53::HealthCheck.HealthCheckTags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder healthCheckTags(java.util.List<java.lang.Object> healthCheckTags) {
            this.healthCheckTags = healthCheckTags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnHealthCheckProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnHealthCheckProps build() {
            return new Jsii$Proxy(healthCheckConfig, healthCheckTags);
        }
    }

    /**
     * An implementation for {@link CfnHealthCheckProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnHealthCheckProps {
        private final java.lang.Object healthCheckConfig;
        private final java.lang.Object healthCheckTags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.healthCheckConfig = this.jsiiGet("healthCheckConfig", java.lang.Object.class);
            this.healthCheckTags = this.jsiiGet("healthCheckTags", java.lang.Object.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.Object healthCheckConfig, final java.lang.Object healthCheckTags) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.healthCheckConfig = java.util.Objects.requireNonNull(healthCheckConfig, "healthCheckConfig is required");
            this.healthCheckTags = healthCheckTags;
        }

        @Override
        public java.lang.Object getHealthCheckConfig() {
            return this.healthCheckConfig;
        }

        @Override
        public java.lang.Object getHealthCheckTags() {
            return this.healthCheckTags;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("healthCheckConfig", om.valueToTree(this.getHealthCheckConfig()));
            if (this.getHealthCheckTags() != null) {
                data.set("healthCheckTags", om.valueToTree(this.getHealthCheckTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-route53.CfnHealthCheckProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnHealthCheckProps.Jsii$Proxy that = (CfnHealthCheckProps.Jsii$Proxy) o;

            if (!healthCheckConfig.equals(that.healthCheckConfig)) return false;
            return this.healthCheckTags != null ? this.healthCheckTags.equals(that.healthCheckTags) : that.healthCheckTags == null;
        }

        @Override
        public int hashCode() {
            int result = this.healthCheckConfig.hashCode();
            result = 31 * result + (this.healthCheckTags != null ? this.healthCheckTags.hashCode() : 0);
            return result;
        }
    }
}

==> route53-1.100.0-sources.jar: software/amazon/awscdk/services/route53/CfnHealthCheckProps.java <==
package software.amazon.awscdk.services.route53;

/**
 * Properties for defining a `AWS::Route53::HealthCheck`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-20T16:34:22.478Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.route53.$Module.class, fqn = "@aws-cdk/aws-route53.CfnHealthCheckProps")
@software.amazon.jsii.Jsii.Proxy(CfnHealthCheckProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnHealthCheckProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::Route53::HealthCheck.HealthCheckConfig`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getHealthCheckConfig();

    /**
     * `AWS::Route53::HealthCheck.HealthCheckTags`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getHealthCheckTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnHealthCheckProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnHealthCheckProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnHealthCheckProps> {
        private java.lang.Object healthCheckConfig;
        private java.lang.Object healthCheckTags;

        /**
         * Sets the value of {@link CfnHealthCheckProps#getHealthCheckConfig}
         * @param healthCheckConfig `AWS::Route53::HealthCheck.HealthCheckConfig`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder healthCheckConfig(software.amazon.awscdk.services.route53.CfnHealthCheck.HealthCheckConfigProperty healthCheckConfig) {
            this.healthCheckConfig = healthCheckConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnHealthCheckProps#getHealthCheckConfig}
         * @param healthCheckConfig `AWS::Route53::HealthCheck.HealthCheckConfig`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder healthCheckConfig(software.amazon.awscdk.core.IResolvable healthCheckConfig) {
            this.healthCheckConfig = healthCheckConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnHealthCheckProps#getHealthCheckTags}
         * @param healthCheckTags `AWS::Route53::HealthCheck.HealthCheckTags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder healthCheckTags(software.amazon.awscdk.core.IResolvable healthCheckTags) {
            this.healthCheckTags = healthCheckTags;
            return this;
        }

        /**
         * Sets the value of {@link CfnHealthCheckProps#getHealthCheckTags}
         * @param healthCheckTags `AWS::Route53::HealthCheck.HealthCheckTags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder healthCheckTags(java.util.List<? extends java.lang.Object> healthCheckTags) {
            this.healthCheckTags = healthCheckTags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnHealthCheckProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnHealthCheckProps build() {
            return new Jsii$Proxy(healthCheckConfig, healthCheckTags);
        }
    }

    /**
     * An implementation for {@link CfnHealthCheckProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnHealthCheckProps {
        private final java.lang.Object healthCheckConfig;
        private final java.lang.Object healthCheckTags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.healthCheckConfig = software.amazon.jsii.Kernel.get(this, "healthCheckConfig", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.healthCheckTags = software.amazon.jsii.Kernel.get(this, "healthCheckTags", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.Object healthCheckConfig, final java.lang.Object healthCheckTags) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.healthCheckConfig = java.util.Objects.requireNonNull(healthCheckConfig, "healthCheckConfig is required");
            this.healthCheckTags = healthCheckTags;
        }

        @Override
        public final java.lang.Object getHealthCheckConfig() {
            return this.healthCheckConfig;
        }

        @Override
        public final java.lang.Object getHealthCheckTags() {
            return this.healthCheckTags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("healthCheckConfig", om.valueToTree(this.getHealthCheckConfig()));
            if (this.getHealthCheckTags() != null) {
                data.set("healthCheckTags", om.valueToTree(this.getHealthCheckTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-route53.CfnHealthCheckProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnHealthCheckProps.Jsii$Proxy that = (CfnHealthCheckProps.Jsii$Proxy) o;

            if (!healthCheckConfig.equals(that.healthCheckConfig)) return false;
            return this.healthCheckTags != null ? this.healthCheckTags.equals(that.healthCheckTags) : that.healthCheckTags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.healthCheckConfig.hashCode();
            result = 31 * result + (this.healthCheckTags != null ? this.healthCheckTags.hashCode() : 0);
            return result;
        }
    }
}
